@@ -8,4 +8,8 @@
 # ==================================================================
 
 # 当前版本号
-PACKAGE_VERSION = '3.0.1'
+PACKAGE_VERSION = '3.0.2'
+
+VERSION = tuple(PACKAGE_VERSION.split("."))
+
+default_app_config = "django_kelove_db.apps.DjangoKeloveDbConfig"
